@@ -38,3 +38,17 @@ def fix_many_to_many():
                 dups.append(s)
         for s in dups:
             s.delete()
+
+def remove_nonoccurrences():
+    Lemma.objects.filter(frequency=0.0).delete()
+    WordForm.objects.filter(frequency=0.0).delete()
+    SpelledAs.objects.filter(frequency=0.0).delete()
+    bads = []
+    for o in Orthography.objects.all():
+        if o.get_frequency() == 0.0:
+            bads.append(o)
+    for t in Transcription.objects.all():
+        if t.get_frequency == 0.0:
+            bads.append(t)
+    for i in bads:
+        i.delete()
