@@ -282,7 +282,7 @@ def doNGramAnalysis():
 def analyze_block(files):
     output = []
     for f in files:
-        comp = pickle.load(os.path.join(settings.TEMP_DIR,f))
+        comp = pickle.load(open(os.path.join(settings.TEMP_DIR,f),'r'))
         for c in comp:
             q = c[0]
             s = c[1]
